Skip to contents

Methods for classes PhyloMArrayLM and ConsensusTreeModel

Usage

getParameters(object, consensus = TRUE)

# S4 method for class 'PhyloMArrayLM'
getParameters(object, consensus = TRUE)

# S4 method for class 'ConsensusTreeModel'
getParameters(object, consensus = TRUE)

plotParameters(object, ...)

# S4 method for class 'PhyloMArrayLM'
plotParameters(object, ...)

# S4 method for class 'ConsensusTreeModel'
plotParameters(object, ...)

# S4 method for class 'PhyloMArrayLM'
show(object)

# S4 method for class 'ConsensusTreeModel'
show(object)

logLikelihood(object)

# S4 method for class 'PhyloMArrayLM'
logLikelihood(object)

consensusTree(object)

# S4 method for class 'PhyloMArrayLM'
consensusTree(object)

# S4 method for class 'ConsensusTreeModel'
consensusTree(object)

Arguments

object

an object of class PhyloMArrayLM-class or ConsensusTreeModel-class

consensus

if TRUE (the default), getParameters returns the consensus parameters as a named vector. Otherwise, it returns the individual fits for all genes.

...

further parameters to be based to hist, including breaks.

Value

Depending on the method, a named vector, a data frame, or a plot.