The phyloDE Package for Differential Expression Analysis
phyloDE-package.RdThe phyloDE package fits linear model on inter-species gene expression data,
combining Phylogenetic Comparative Methods implemented in phylolm
with moderated statistics tailored for gene expression implemented in limma.
With a design matrix that expresses a grouping conditions at the tip of a phylogeny,
phyloDE can perform Differential Expression analysis.
The main function of the package is phylolmFit,
that inherits from the interfaces of both phylolm
and limma.