Normalize RNASeq count data using gene lengths
lengthNormalizeRNASeq.RdThis function normalizes a count matrix, using the matrix of length, and an appropriate transformation.
Arguments
- countMatrix
The RNASeq count matrix. Rows and columns should be named.
- lengthMatrix
The associated length matrix. Should have the same dimensions as
countMatrix, with the same names.- normalisationFactor
Normalization factors to scale the raw library sizes, as computed e.g. by
calcNormFactors.- lengthNormalization
one of "none" (no correction), "TPM" (default) or "RPKM". See details.
- dataTransformation
one of "log2", "asin(sqrt)" or "sqrt." See details.