Heatmap with Phylogeny Structured Columns
phyHeatmap.RdThis function uses the heatmap function to plot
the (normalized) data, using the phylogenetic tree as the column
dendogram.
Usage
phyHeatmap(
object,
design = NULL,
coef = NULL,
phy,
scale = "none",
ColSideColors = NULL,
add.expr = NULL,
...
)Arguments
- object
a matrix data object containing normalized expression values, with rows corresponding to genes and columns to samples (species).
- design
the design matrix of the experiment, with rows corresponding to samples and columns to coefficients to be estimated. Defaults to the unit vector (intercept).
- coef
column number or column name specifying which coefficient or contrast of the linear model in the
designmatrix is of interest. If leftNULL, defaults to the last column ofdesign.- phy
an object of class
phylo, representing the phylogenetic relationships between the species. It must be dated and ultrametric. If the column names ofobjectfollow the patternSpeciesName_SampleIdorSpeciesName.SampleId, an automatic matching of the samples on the tip of the tree is performed. Otherwise, the tree tip labels must match with species names incol_species(see below). The tip labels of the tree can also match exactly the names as the columns ofobject, so that the tree directly includes all the replicates.- scale
character indicating if the values on the heatmap should be centered and scaled in either the row direction or the column direction, or none. The default is "none", as the data is assumed to be already normalized. This scaling only affects the colour scale; it does not scale the original data. See documentation of
heatmap.- ColSideColors
(optional) character vector of length
ncol(object)containing the color names for a horizontal side bar that may be used to annotate the columns of the heatmap. If leftNULLanddesignis specified, the column of thedesignmatrix corresponding tocoefwill be used.- add.expr
expression that will be evaluated after the call to image. Can be used to add components to the plot. See documentation of
heatmap. If leftNULLanddesignis specified, the column of thedesignmatrix corresponding tocoefwill be used to draw vertical lines.- ...
further arguments to be passed to
heatmap. ArgumentColvdefaults to the phylogeny, and cannot be overwritten.
Value
Invisibly, a list, see heatmap.